==> Evols_3D_Lanterns_and_Chains_v1.1.zip: README.md <==
# Evol's 3D Chains & Lanterns Resource Pack

Welcome to **Evol's 3D Chains & Lanterns**, a resource pack designed to bring a new dimension to your Minecraft world! This pack enhances the visual experience of chains, lanterns, and soul lanterns by making them completely 3D and providing updated texture animations, all in a crisp 32x32 resolution.

## Features

- **Fully 3D Chains:** Say goodbye to flat chains! Our pack transforms them into beautiful, three-dimensional models, adding depth and realism to your builds.

- **3D Lanterns & Soul Lanterns:** Experience your light sources like never before. Both regular lanterns and soul lanterns are now fully 3D fitting seamlessly into any environment. 

- **Animated Textures:** Enjoy subtle yet captivating animated textures that breathe life into these common decorative blocks.

- **32x32 Resolution:** High-quality textures without being overly demanding, providing a perfect balance between performance and visual fidelity.

- **No Requirements:** This resource pack works with vanilla Minecraft, no mods or external loaders are necessary.

- **Shader Friendly:** While not required, **Evol's 3D Chains & Lanterns** includes PBR mapping for all textures, and truly shines when paired with your favorite shaders, further enhancing the dynamic lighting and visual effects.

## Installation

1. **Download** the resource pack file.

2. **Open Minecraft** and navigate to "Options" -> "Resource Packs" -> "Open Pack Folder".

3. **Drag and Drop** the downloaded `.zip` file into the resource packs folder.

4. **Activate** the resource pack from within Minecraft by moving it from the "Available Resource Packs" to the "Selected Resource Packs" column. Make sure it is above any other packs that might modify chains or lanterns.

5. **Enjoy!**

## Compatibility

This resource pack is compatible with Minecraft Java Edition 1.16.x and newer versions. As it only modifies models and textures for specific blocks, it should be compatible with most other resource packs, provided it is placed higher in the resource pack order.

## Support & Feedback

If you encounter any bugs, have suggestions, or just want to share your amazing builds using this pack, please feel free to reach out through [mention your preferred contact method here, e.g., a specific forum thread, Discord, GitHub issues]. Your feedback helps make this pack even better!

## Changelog

### Version 1.0.0 (Initial Release)

- Initial release of Evol's 3D Chains & Lanterns.

- Implemented full 3D models for all chain segments.

- Implemented full 3D models for regular lanterns.

- Implemented full 3D models for soul lanterns.

- Added animated textures for chains.

- Added animated textures for lanterns.

- Added animated textures for soul lanterns.

- All textures updated to 32x32 resolution.

## Version 1.01 (PBR Update)

- All textures include PBR Textures for use with shaders now.

## Version 1.02 (PBR Update)

- All PBR Textures updated to work appropriately with the top shaders available. (BSL, ComplementaryUnbound, ComplementaryReimagined, photon, and Solas). My hope is getting a good pbr texture that works well with all of these should mean they work well with most all shaders. 

---

Thank you for downloading and using **Evol's 3D Chains & Lanterns**! We hope you enjoy the enhanced visual experience in your Minecraft adventures.

==> Evols_3D_Lanterns_and_Chains_v1.13.zip: README.md <==
# Evol's 3D Chains & Lanterns Resource Pack

Welcome to **Evol's 3D Chains & Lanterns**, a resource pack designed to bring a new dimension to your Minecraft world! This pack enhances the visual experience of chains, lanterns, and soul lanterns by making them completely 3D and providing updated texture animations, all in a crisp 32x32 resolution.

## Features

- **Fully 3D Chains:** Say goodbye to flat chains! Our pack transforms them into beautiful, three-dimensional models, adding depth and realism to your builds.

- **3D Lanterns & Soul Lanterns:** Experience your light sources like never before. Both regular lanterns and soul lanterns are now fully 3D fitting seamlessly into any environment. 

- **Animated Textures:** Enjoy subtle yet captivating animated textures that breathe life into these common decorative blocks.

- **32x32 Resolution:** High-quality textures without being overly demanding, providing a perfect balance between performance and visual fidelity.

- **No Requirements:** This resource pack works with vanilla Minecraft, no mods or external loaders are necessary.

- **Shader Friendly:** While not required, **Evol's 3D Chains & Lanterns** includes PBR mapping for all textures, and truly shines when paired with your favorite shaders, further enhancing the dynamic lighting and visual effects.

## Installation

1. **Download** the resource pack file.

2. **Open Minecraft** and navigate to "Options" -> "Resource Packs" -> "Open Pack Folder".

3. **Drag and Drop** the downloaded `.zip` file into the resource packs folder.

4. **Activate** the resource pack from within Minecraft by moving it from the "Available Resource Packs" to the "Selected Resource Packs" column. Make sure it is above any other packs that might modify chains or lanterns.

5. **Enjoy!**

## Compatibility

This resource pack is compatible with Minecraft Java Edition 1.16.x and newer versions. As it only modifies models and textures for specific blocks, it should be compatible with most other resource packs, provided it is placed higher in the resource pack order.

## Support & Feedback

If you encounter any bugs, have suggestions, or just want to share your amazing builds using this pack, please feel free to reach out through [mention your preferred contact method here, e.g., a specific forum thread, Discord, GitHub issues]. Your feedback helps make this pack even better!

## Changelog

### Version 1.0.0 (Initial Release)

- Initial release of Evol's 3D Chains & Lanterns.

- Implemented full 3D models for all chain segments.

- Implemented full 3D models for regular lanterns.

- Implemented full 3D models for soul lanterns.

- Added animated textures for chains.

- Added animated textures for lanterns.

- Added animated textures for soul lanterns.

- All textures updated to 32x32 resolution.

## Version 1.01 (PBR Update)

- All textures include PBR Textures for use with shaders now.

## Version 1.02 (PBR Update)

- All PBR Textures updated to work appropriately with the top shaders available. (BSL, ComplementaryUnbound, ComplementaryReimagined, photon, and Solas). My hope is getting a good pbr texture that works well with all of these should mean they work well with most all shaders. 

## Version1.10 (Copper Update)

 - Added All of the copper variants.



## Version1.11 (Copper Update)

 - Fixed All of the waxed copper variants.

---

Thank you for downloading and using **Evol's 3D Chains & Lanterns**! We hope you enjoy the enhanced visual experience in your Minecraft adventures.
